Guard

Struct Guard 

pub struct Guard<'lock_mem, 'facet> { /* private fields */ }
Contains the guard, the data ptr, and drop vtable to free the lock

Note

The contained MaybeMut is NOT guaranteed to be Mut

For example, RwLock also needs a lock and guard for a read.

Implementations

Source

impl<'lock, 'facet> Guard<'lock, 'facet>

pub fn shape(&self) -> &'static Shape

Returns the Shape of the underlying MaybeMut

pub fn as_peek<'s>(&'s self) -> Peek<'s, 'facet>

It is always possible to get a Peek from a Guard

pub fn as_poke<'s>(&'s mut self) -> Option<Poke<'s, 'facet>>

If the Guard contains a Poke, this will return Some(Poke) assuming Poke can be reborrowed.

pub fn as_maybe<'s>(&'s mut self) -> MaybeMut<'s, 'facet>

Returns either a Poke or a Peek depending on whats available via the guard (read lock or write lock)