Crate facet_maybe_mut

Crate facet_maybe_mut 

This crate provides the MaybeMut that abstracts away smart pointers, locks etc as if they did not exist.

This is usually not desirable, because it can easily lead to deadlocks and really bad performance. But sometimes, you simply do not care (for example in simple UI applications)

Structs

Guard
Contains the guard, the data ptr, and drop vtable to free the lock
MakeLockError

Enums

MakeLockErrorKind
MaybeMut
Some reference to a type that implements Facet that may be mut or not.